pub struct ClawCache<K, V> { /* private fields */ }Expand description
Implementations
Sourceimpl<K, V> ClawCache<K, V>
impl<K, V> ClawCache<K, V>
Sourcepub fn new(capacity: usize) -> ClawResult<Self>
pub fn new(capacity: usize) -> ClawResult<Self>
Create a new cache with the given maximum capacity (number of entries).
Errors
Returns ClawError::Cache if capacity is zero.
Sourcepub fn insert(&mut self, key: K, value: V)
pub fn insert(&mut self, key: K, value: V)
Insert value under key. If the cache is full, the LRU entry is
evicted first.
Sourcepub fn get(&mut self, key: &K) -> Option<&V>
pub fn get(&mut self, key: &K) -> Option<&V>
Return a reference to the cached value for key, or None if not
present. Accessing an entry marks it as most-recently used.
Sourcepub fn remove(&mut self, key: &K) -> Option<V>
pub fn remove(&mut self, key: &K) -> Option<V>
Remove and return the value for key, if present.
Sourcepub fn invalidate(&mut self, key: &K)
pub fn invalidate(&mut self, key: &K)
Invalidate (remove) the value for key, if present.