Module engine

Module engine 

Main engine entry point for claw-core.

ClawEngine is the primary handle through which callers interact with the embedded SQLite database. It owns the SQLx connection pool, an internal LRU cache for MemoryRecords, applies migrations on startup (when auto_migrate is enabled), and exposes methods for interacting with the various store modules.

Structs

ClawEngine
The main entry point for claw-core.
ClawStats
Comprehensive runtime statistics for a ClawEngine instance.
DbStats
Database-level statistics for a ClawEngine instance.