Evidence

Struct Evidence 

pub struct Evidence {
Show 17 fields pub name: String, pub status: String, pub duration_ms: u64, pub artifact_refs: Vec<String>, pub summary: String, pub revision_id: Option<ObjectId>, pub command: Option<String>, pub exit_code: Option<i32>, pub started_at_ms: Option<u64>, pub ended_at_ms: Option<u64>, pub environment_digest: Option<String>, pub runner_identity: Option<String>, pub log_digest: Option<String>, pub artifact_digest: Option<String>, pub expires_at_ms: Option<u64>, pub trust_domain: Option<String>, pub signature: Option<Vec<u8>>,
}

Fields

name: Stringstatus: Stringduration_ms: u64artifact_refs: Vec<String>summary: Stringrevision_id: Option<ObjectId>command: Option<String>exit_code: Option<i32>started_at_ms: Option<u64>ended_at_ms: Option<u64>environment_digest: Option<String>runner_identity: Option<String>log_digest: Option<String>artifact_digest: Option<String>expires_at_ms: Option<u64>trust_domain: Option<String>signature: Option<Vec<u8>>

Implementations

Source

impl Evidence

pub fn command(&self) -> &str

Returns the value of command, or the default value if command is unset.

pub fn exit_code(&self) -> i32

Returns the value of exit_code, or the default value if exit_code is unset.

pub fn started_at_ms(&self) -> u64

Returns the value of started_at_ms, or the default value if started_at_ms is unset.

pub fn ended_at_ms(&self) -> u64

Returns the value of ended_at_ms, or the default value if ended_at_ms is unset.

pub fn environment_digest(&self) -> &str

Returns the value of environment_digest, or the default value if environment_digest is unset.

pub fn runner_identity(&self) -> &str

Returns the value of runner_identity, or the default value if runner_identity is unset.

pub fn log_digest(&self) -> &str

Returns the value of log_digest, or the default value if log_digest is unset.

pub fn artifact_digest(&self) -> &str

Returns the value of artifact_digest, or the default value if artifact_digest is unset.

pub fn expires_at_ms(&self) -> u64

Returns the value of expires_at_ms, or the default value if expires_at_ms is unset.

pub fn trust_domain(&self) -> &str

Returns the value of trust_domain, or the default value if trust_domain is unset.

pub fn signature(&self) -> &[u8]

Returns the value of signature, or the default value if signature is unset.