Module transaction

Module transaction 

Transaction wrapper for claw-core.

Structs

CacheRecord
A key-value cache record that can be staged for deferred cache operations.
ClawTransaction
A wrapper around a SQLite transaction with staged memory operations.

Enums

CacheOp
A deferred cache mutation that should be applied after a successful commit.
StagedMemoryOp
A database write operation staged in ClawTransaction.