pub enum CacheOp {
Insert(Uuid, CacheRecord),
Delete(Uuid),
Clear,
}Expand description
A deferred cache mutation that should be applied after a successful commit.
Variants
Insert(Uuid, CacheRecord)
Insert or update the record identified by the given Uuid.
Delete(Uuid)
Remove the record identified by the given Uuid from the cache.
Clear
Invalidate the entire cache.