pub struct CofMigrationPlan { /* private fields */ }Expand description
Planned handling for an observed COF version.
Implementations
Sourceimpl CofMigrationPlan
impl CofMigrationPlan
Sourcepub fn source_version(self) -> u8
pub fn source_version(self) -> u8
Version byte found in the encoded object.
Sourcepub fn target_version(self) -> u8
pub fn target_version(self) -> u8
Version byte this crate writes by default.
Sourcepub fn support(self) -> CofVersionSupport
pub fn support(self) -> CofVersionSupport
Compatibility class for the source version.
Sourcepub fn can_write_source_version(self) -> bool
pub fn can_write_source_version(self) -> bool
Return true when writing this source version is supported.
Sourcepub fn requires_migration(self) -> bool
pub fn requires_migration(self) -> bool
Return true when decoding requires an explicit migration step.