Transaction wrapper for claw-core.
Structs
- Cache
Record - A key-value cache record that can be staged for deferred cache operations.
- Claw
Transaction - A wrapper around a SQLite transaction with staged memory operations.
Enums
- CacheOp
- A deferred cache mutation that should be applied after a successful commit.
- Staged
Memory Op - A database write operation staged in
ClawTransaction.